==> chromium-44.0.2403.84.tar.xz: chromium-44.0.2403.84/chrome/browser/media/router/mock_media_router.h <==
// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_MEDIA_ROUTER_MOCK_MEDIA_ROUTER_H_
#define CHROME_BROWSER_MEDIA_ROUTER_MOCK_MEDIA_ROUTER_H_

#include <string>
#include <vector>

#include "chrome/browser/media/router/issue.h"
#include "chrome/browser/media/router/media_route.h"
#include "chrome/browser/media/router/media_router.h"
#include "chrome/browser/media/router/media_sink.h"
#include "chrome/browser/media/router/media_source.h"
#include "testing/gmock/include/gmock/gmock.h"

namespace media_router {

// Mocked out MediaRouter used in tests.
class MockMediaRouter : public MediaRouter {
 public:
  MockMediaRouter();
  virtual ~MockMediaRouter();

  MOCK_METHOD3(RequestRoute,
               void(const MediaSourceId& source,
                    const MediaSinkId& sink_id,
                    const MediaRouteResponseCallback& callback));
  MOCK_METHOD1(CloseRoute, void(const MediaRouteId& route_id));
  MOCK_METHOD2(PostMessage,
               void(const MediaRouteId& route_id, const std::string& message));

  MOCK_METHOD1(RegisterMediaSinksObserver, bool(MediaSinksObserver* observer));
  MOCK_METHOD1(UnregisterMediaSinksObserver,
               void(MediaSinksObserver* observer));
  MOCK_METHOD1(RegisterMediaRoutesObserver,
               bool(MediaRoutesObserver* observer));
  MOCK_METHOD1(UnregisterMediaRoutesObserver,
               void(MediaRoutesObserver* observer));
};

}  // namespace media_router

#endif  // CHROME_BROWSER_MEDIA_ROUTER_MOCK_MEDIA_ROUTER_H_

==> chromium-45.0.2419.0.tar.xz: chromium-45.0.2419.0/chrome/browser/media/router/mock_media_router.h <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_MEDIA_ROUTER_MOCK_MEDIA_ROUTER_H_
#define CHROME_BROWSER_MEDIA_ROUTER_MOCK_MEDIA_ROUTER_H_

#include <string>
#include <vector>

#include "chrome/browser/media/router/issue.h"
#include "chrome/browser/media/router/media_route.h"
#include "chrome/browser/media/router/media_router.h"
#include "chrome/browser/media/router/media_sink.h"
#include "chrome/browser/media/router/media_source.h"
#include "testing/gmock/include/gmock/gmock.h"

namespace media_router {

// Media Router mock class. Used for testing purposes.
class MockMediaRouter : public MediaRouter {
 public:
  MockMediaRouter();
  virtual ~MockMediaRouter();

  MOCK_METHOD3(CreateRoute,
               void(const MediaSourceId& source_id,
                    const MediaSinkId& sink_id,
                    const MediaRouteResponseCallback& callback));
  MOCK_METHOD1(CloseRoute, void(const MediaRouteId& route_id));
  MOCK_METHOD2(PostMessage,
               void(const MediaRouteId& route_id, const std::string& message));
  MOCK_METHOD1(ClearIssue, void(const Issue::IssueId& issue_id));
  MOCK_METHOD1(AddIssuesObserver, void(IssuesObserver* observer));
  MOCK_METHOD1(RemoveIssuesObserver, void(IssuesObserver* observer));

  MOCK_METHOD1(RegisterMediaSinksObserver, void(MediaSinksObserver* observer));
  MOCK_METHOD1(UnregisterMediaSinksObserver,
               void(MediaSinksObserver* observer));
  MOCK_METHOD1(RegisterMediaRoutesObserver,
               void(MediaRoutesObserver* observer));
  MOCK_METHOD1(UnregisterMediaRoutesObserver,
               void(MediaRoutesObserver* observer));
};

}  // namespace media_router

#endif  // CHROME_BROWSER_MEDIA_ROUTER_MOCK_MEDIA_ROUTER_H_
